@@ -27,6 +27,15 @@ _OPENAPI_ENDPOINT_PARAMS = (
 )
 
 
+def parse_query_response(response: QueryResponse, unary_query: bool):
+    if unary_query:
+        response._data_store.pop('results', None)
+    else:
+        response._data_store.pop('matches', None)
+        response._data_store.pop('namespace', None)
+    return response
+
+
 class Index(ApiClient):
 
     def __init__(self, index_name: str, pool_threads=1):
@@ -84,7 +93,7 @@ class Index(ApiClient):
         return self._vector_api.fetch(*args, **kwargs)
 
     @validate_and_convert_errors
-    def query(self, queries, **kwargs):
+    def query(self, vector=[], id='', queries=[], **kwargs):
         _check_type = kwargs.pop('_check_type', False)
 
         def _query_transform(item):
@@ -97,14 +106,17 @@ class Index(ApiClient):
                 return QueryVector(values=item, _check_type=_check_type)
             raise ValueError(f"Invalid query vector value passed: cannot interpret type {type(item)}")
 
-        return self._vector_api.query(
+        response = self._vector_api.query(
             QueryRequest(
                 queries=list(map(_query_transform, queries)),
+                vector=vector,
+                id=id,
                 _check_type=_check_type,
                 **{k: v for k, v in kwargs.items() if k not in _OPENAPI_ENDPOINT_PARAMS}
             ),
             **{k: v for k, v in kwargs.items() if k in _OPENAPI_ENDPOINT_PARAMS}
         )
+        return parse_query_response(response, vector or id)
 
     @validate_and_convert_errors
     def update(self, id, **kwargs):
